@@ -2,7 +2,7 @@
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2005-2016 Zarafa Deutschland GmbH
- * SPDX-FileCopyrightText: Copyright 2020-2022 grommunio GmbH
+ * SPDX-FileCopyrightText: Copyright 2020-2024 grommunio GmbH
  */
 
 /**
@@ -141,7 +141,7 @@ abstract class BaseRecurrence {
 	 *
 	 * @param string $rdata Binary string
 	 *
-	 * @return (((false|int|mixed|string)[]|int)[]|int|mixed)[]|null recurrence data
+	 * @return null|(((false|int|mixed|string)[]|int)[]|int|mixed)[] recurrence data
 	 *
 	 * @psalm-return array{changed_occurrences: array<int, array{basedate: false|int, start: int, end: int, bitmask: mixed, subject?: false|string, remind_before?: mixed, reminder_set?: mixed, location?: false|string, busystatus?: mixed, alldayevent?: mixed, label?: mixed, ex_start_datetime?: mixed, ex_end_datetime?: mixed, ex_orig_date?: mixed}>, deleted_occurrences: list<int>, type?: int|mixed, subtype?: mixed, month?: mixed, everyn?: mixed, regen?: mixed, monthday?: mixed, weekdays?: 0|mixed, nday?: mixed, term?: int|mixed, numoccur?: mixed, numexcept?: mixed, numexceptmod?: mixed, start?: int, end?: int, startocc?: mixed, endocc?: mixed}|null
 	 */
@@ -621,6 +621,7 @@ abstract class BaseRecurrence {
 		$rdata = pack("vvvvv", 0x3004, 0x3004, $rtype, (int) $this->recur["subtype"], MAPI_CAL_DEFAULT);
 		$weekstart = 1; // monday
 		$forwardcount = 0;
+		$count = 0;
 		$restocc = 0;
 		$dayofweek = (int) gmdate("w", (int) $this->recur["start"]); // 0 (for Sunday) through 6 (for Saturday)
 
@@ -974,6 +975,7 @@ abstract class BaseRecurrence {
 			case IDC_RCEV_PAT_ERB_END:
 				$rdata .= pack("V", 10);
 				break;
+
 				// After a number of times
 			case IDC_RCEV_PAT_ERB_AFTERNOCCUR:
 				if (!isset($this->recur["numoccur"])) {
@@ -982,6 +984,7 @@ abstract class BaseRecurrence {
 
 				$rdata .= pack("V", (int) $this->recur["numoccur"]);
 				break;
+
 				// Never ends
 			case IDC_RCEV_PAT_ERB_NOEND:
 				$rdata .= pack("V", 0);
@@ -1006,7 +1009,7 @@ abstract class BaseRecurrence {
 		$items = $deleted_items;
 
 		foreach ($changed_items as $changed_item) {
-			array_push($items, $changed_item["basedate"]);
+			array_push($items, $this->dayStartOf($changed_item["basedate"]));
 		}
 
 		sort($items);
@@ -1041,6 +1044,7 @@ abstract class BaseRecurrence {
 			case IDC_RCEV_PAT_ERB_END:
 				$rdata .= pack("V", $this->unixDataToRecurData((int) $this->recur["end"]));
 				break;
+
 				// After a number of times
 			case IDC_RCEV_PAT_ERB_AFTERNOCCUR:
 				// @todo: calculate enddate with intval($this->recur["startocc"]) + intval($this->recur["duration"]) > 24 hour
@@ -1190,6 +1194,7 @@ abstract class BaseRecurrence {
 
 				$rdata .= pack("V", $this->unixDataToRecurData((int) $this->recur["end"]));
 				break;
+
 				// Never ends
 			case IDC_RCEV_PAT_ERB_NOEND:
 			default:
@@ -1400,7 +1405,8 @@ abstract class BaseRecurrence {
 			if ($this->tz["timezone"] != 0) {
 				// Create user readable timezone information
 				$timezone = sprintf(
-					"(GMT %s%02d:%02d)",-$this->tz["timezone"] > 0 ? "+" : "-",
+					"(GMT %s%02d:%02d)",-
+					$this->tz["timezone"] > 0 ? "+" : "-",
 					abs($this->tz["timezone"] / 60),
 					abs($this->tz["timezone"] % 60)
 				);
@@ -1576,20 +1582,6 @@ abstract class BaseRecurrence {
 		return $tz["timezone"];
 	}
 
-	/**
-	 * getWeekNr() returns the week nr of the month (ie first week of february is 1).
-	 *
-	 * @param mixed $date
-	 *
-	 * @return float|int
-	 */
-	public function getWeekNr($date) {
-		$gmdate = gmtime($date);
-		$gmdate["tm_mday"] = 0;
-
-		return strftime("%W", $date) - strftime("%W", gmmktime($gmdate)) + 1;
-	}
-
 	/**
 	 * parseTimezone parses the timezone as specified in named property 0x8233
 	 * in Outlook calendar messages. Returns the timezone in minutes negative
@@ -1616,29 +1608,6 @@ abstract class BaseRecurrence {
 		return pack("lllllvvllvlvvlv", $tz["timezone"], 0, $tz["timezonedst"], 0, $tz["dstendmonth"], $tz["dstendweek"], $tz["dstendhour"], 0, 0, 0, $tz["dststartmonth"], $tz["dststartweek"], $tz["dststarthour"], 0, 0);
 	}
 
-	/**
-	 * createTimezone creates the timezone as specified in the named property 0x8233
-	 * see also parseTimezone()
-	 * $tz is an array with the timezone data.
-	 *
-	 * @param mixed $tz
-	 *
-	 * @return false|string
-	 */
-	public function createTimezone($tz) {
-		return pack(
-			"lxxxxlxxxxlvvxxxxxxxxxxlvvxxxxxx",
-			$tz["timezone"],
-			array_key_exists("timezonedst", $tz) ? $tz["timezonedst"] : 0,
-			array_key_exists("dstendmonth", $tz) ? $tz["dstendmonth"] : 0,
-			array_key_exists("dstendweek", $tz) ? $tz["dstendweek"] : 0,
-			array_key_exists("dstendhour", $tz) ? $tz["dstendhour"] : 0,
-			array_key_exists("dststartmonth", $tz) ? $tz["dststartmonth"] : 0,
-			array_key_exists("dststartweek", $tz) ? $tz["dststartweek"] : 0,
-			array_key_exists("dststarthour", $tz) ? $tz["dststarthour"] : 0
-		);
-	}
-
 	/**
 	 * toGMT returns a timestamp in GMT time for the time and timezone given.
 	 *
@@ -1720,6 +1689,7 @@ abstract class BaseRecurrence {
 	 */
 	public function getItems($start, $end, $limit = 0, $remindersonly = false): array {
 		$items = [];
+		$firstday = 0;
 
 		if (isset($this->recur)) {
 			// Optimization: remindersonly and default reminder is off; since only exceptions with reminder set will match, just look which
