@@ -350,3 +350,259 @@ function getUidFromGoid($goid) {
 
 	return null;
 }
+
+/**
+ * Converts a MAPI property tag into a human readable value.
+ *
+ * This depends on the definition of the property tag in core
+ *
+ * @example prop2Str(0x0037001e) => 'PR_SUBJECT'
+ *
+ * @param mixed $property
+ *
+ * @return string the symbolic name of the property tag
+ */
+function prop2Str($property) {
+	if (is_integer($property)) {
+		// Retrieve constants categories, zcore provides them in 'Core'
+		foreach (get_defined_constants(true)['Core'] as $key => $value) {
+			if ($property == $value && substr($key, 0, 3) == 'PR_') {
+				return $key;
+			}
+		}
+
+		return sprintf("0x%08X", $property);
+	}
+
+	return $property;
+}
+
+/**
+ * Converts all constants of restriction into a human readable strings.
+ *
+ * @param mixed $restriction
+ */
+function simplifyRestriction($restriction) {
+	if (!is_array($restriction)) {
+		return $restriction;
+	}
+
+	switch ($restriction[0]) {
+		case RES_AND:
+			$restriction[0] = "RES_AND";
+			if (isset($restriction[1][0]) && is_array($restriction[1][0])) {
+				foreach ($restriction[1] as &$res) {
+					$res = simplifyRestriction($res);
+				}
+				unset($res);
+			}
+			elseif (isset($restriction[1]) && $restriction[1]) {
+				$restriction[1] = simplifyRestriction($restriction[1]);
+			}
+			break;
+
+		case RES_OR:
+			$restriction[0] = "RES_OR";
+			if (isset($restriction[1][0]) && is_array($restriction[1][0])) {
+				foreach ($restriction[1] as &$res) {
+					$res = simplifyRestriction($res);
+				}
+				unset($res);
+			}
+			elseif (isset($restriction[1]) && $restriction[1]) {
+				$restriction[1] = simplifyRestriction($restriction[1]);
+			}
+			break;
+
+		case RES_NOT:
+			$restriction[0] = "RES_NOT";
+			$restriction[1][0] = simplifyRestriction($restriction[1][0]);
+			break;
+
+		case RES_COMMENT:
+			$restriction[0] = "RES_COMMENT";
+			$res = simplifyRestriction($restriction[1][RESTRICTION]);
+			$props = $restriction[1][PROPS];
+
+			foreach ($props as &$prop) {
+				$propTag = $prop[ULPROPTAG];
+				$propValue = $prop[VALUE];
+
+				unset($prop);
+
+				$prop["ULPROPTAG"] = is_string($propTag) ? $propTag : prop2Str($propTag);
+				$prop["VALUE"] = is_array($propValue) ? $propValue[$propTag] : $propValue;
+			}
+			unset($prop, $restriction[1]);
+
+			$restriction[1]["RESTRICTION"] = $res;
+			$restriction[1]["PROPS"] = $props;
+			break;
+
+		case RES_PROPERTY:
+			$restriction[0] = "RES_PROPERTY";
+			$propTag = $restriction[1][ULPROPTAG];
+			$propValue = $restriction[1][VALUE];
+			$relOp = $restriction[1][RELOP];
+
+			unset($restriction[1]);
+
+			// relop flags
+			$relOpFlags = "";
+			if ($relOp == RELOP_LT) {
+				$relOpFlags = "RELOP_LT";
+			}
+			elseif ($relOp == RELOP_LE) {
+				$relOpFlags = "RELOP_LE";
+			}
+			elseif ($relOp == RELOP_GT) {
+				$relOpFlags = "RELOP_GT";
+			}
+			elseif ($relOp == RELOP_GE) {
+				$relOpFlags = "RELOP_GE";
+			}
+			elseif ($relOp == RELOP_EQ) {
+				$relOpFlags = "RELOP_EQ";
+			}
+			elseif ($relOp == RELOP_NE) {
+				$relOpFlags = "RELOP_NE";
+			}
+			elseif ($relOp == RELOP_RE) {
+				$relOpFlags = "RELOP_RE";
+			}
+
+			$restriction[1]["RELOP"] = $relOpFlags;
+			$restriction[1]["ULPROPTAG"] = is_string($propTag) ? $propTag : prop2Str($propTag);
+			$restriction[1]["VALUE"] = is_array($propValue) ? $propValue[$propTag] : $propValue;
+			break;
+
+		case RES_CONTENT:
+			$restriction[0] = "RES_CONTENT";
+			$propTag = $restriction[1][ULPROPTAG];
+			$propValue = $restriction[1][VALUE];
+			$fuzzyLevel = $restriction[1][FUZZYLEVEL];
+
+			unset($restriction[1]);
+
+			// fuzzy level flags
+			$levels = [];
+
+			if (($fuzzyLevel & FL_SUBSTRING) == FL_SUBSTRING) {
+				$levels[] = "FL_SUBSTRING";
+			}
+			elseif (($fuzzyLevel & FL_PREFIX) == FL_PREFIX) {
+				$levels[] = "FL_PREFIX";
+			}
+			else {
+				$levels[] = "FL_FULLSTRING";
+			}
+
+			if (($fuzzyLevel & FL_IGNORECASE) == FL_IGNORECASE) {
+				$levels[] = "FL_IGNORECASE";
+			}
+
+			if (($fuzzyLevel & FL_IGNORENONSPACE) == FL_IGNORENONSPACE) {
+				$levels[] = "FL_IGNORENONSPACE";
+			}
+
+			if (($fuzzyLevel & FL_LOOSE) == FL_LOOSE) {
+				$levels[] = "FL_LOOSE";
+			}
+
+			$fuzzyLevelFlags = implode(" | ", $levels);
+
+			$restriction[1]["FUZZYLEVEL"] = $fuzzyLevelFlags;
+			$restriction[1]["ULPROPTAG"] = is_string($propTag) ? $propTag : prop2Str($propTag);
+			$restriction[1]["VALUE"] = is_array($propValue) ? $propValue[$propTag] : $propValue;
+			break;
+
+		case RES_COMPAREPROPS:
+			$propTag1 = $restriction[1][ULPROPTAG1];
+			$propTag2 = $restriction[1][ULPROPTAG2];
+
+			unset($restriction[1]);
+
+			$restriction[1]["ULPROPTAG1"] = is_string($propTag1) ? $proptag1 : prop2Str($proptag1);
+			$restriction[1]["ULPROPTAG2"] = is_string($propTag2) ? $propTag2 : prop2Str($propTag2);
+			break;
+
+		case RES_BITMASK:
+			$restriction[0] = "RES_BITMASK";
+			$propTag = $restriction[1][ULPROPTAG];
+			$maskType = $restriction[1][ULTYPE];
+			$maskValue = $restriction[1][ULMASK];
+
+			unset($restriction[1]);
+
+			// relop flags
+			$maskTypeFlags = "";
+			if ($maskType == BMR_EQZ) {
+				$maskTypeFlags = "BMR_EQZ";
+			}
+			elseif ($maskType == BMR_NEZ) {
+				$maskTypeFlags = "BMR_NEZ";
+			}
+
+			$restriction[1]["ULPROPTAG"] = is_string($propTag) ? $propTag : prop2Str($propTag);
+			$restriction[1]["ULTYPE"] = $maskTypeFlags;
+			$restriction[1]["ULMASK"] = $maskValue;
+			break;
+
+		case RES_SIZE:
+			$restriction[0] = "RES_SIZE";
+			$propTag = $restriction[1][ULPROPTAG];
+			$propValue = $restriction[1][CB];
+			$relOp = $restriction[1][RELOP];
+
+			unset($restriction[1]);
+
+			// relop flags
+			$relOpFlags = "";
+			if ($relOp == RELOP_LT) {
+				$relOpFlags = "RELOP_LT";
+			}
+			elseif ($relOp == RELOP_LE) {
+				$relOpFlags = "RELOP_LE";
+			}
+			elseif ($relOp == RELOP_GT) {
+				$relOpFlags = "RELOP_GT";
+			}
+			elseif ($relOp == RELOP_GE) {
+				$relOpFlags = "RELOP_GE";
+			}
+			elseif ($relOp == RELOP_EQ) {
+				$relOpFlags = "RELOP_EQ";
+			}
+			elseif ($relOp == RELOP_NE) {
+				$relOpFlags = "RELOP_NE";
+			}
+			elseif ($relOp == RELOP_RE) {
+				$relOpFlags = "RELOP_RE";
+			}
+
+			$restriction[1]["ULPROPTAG"] = is_string($propTag) ? $propTag : prop2Str($propTag);
+			$restriction[1]["RELOP"] = $relOpFlags;
+			$restriction[1]["CB"] = $propValue;
+			break;
+
+		case RES_EXIST:
+			$propTag = $restriction[1][ULPROPTAG];
+
+			unset($restriction[1]);
+
+			$restriction[1]["ULPROPTAG"] = is_string($propTag) ? $propTag : prop2Str($propTag);
+			break;
+
+		case RES_SUBRESTRICTION:
+			$propTag = $restriction[1][ULPROPTAG];
+			$res = simplifyRestriction($restriction[1][RESTRICTION]);
+
+			unset($restriction[1]);
+
+			$restriction[1]["ULPROPTAG"] = is_string($propTag) ? $propTag : prop2Str($propTag);
+			$restriction[1]["RESTRICTION"] = $res;
+			break;
+	}
+
+	return $restriction;
+}
