@@ -2,7 +2,7 @@
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2005-2016 Zarafa Deutschland GmbH
- * SPDX-FileCopyrightText: Copyright 2020-2022 grommunio GmbH
+ * SPDX-FileCopyrightText: Copyright 2020-2024 grommunio GmbH
  */
 
 /* Search folder properties */
@@ -16,11 +16,14 @@ define('PR_RULE_EXCEPTION_ATLEAST_MESSAGE_SIZEUNIT', mapi_prop_tag(PT_STRING8, 0
 define('PR_RULE_EXCEPTION_ATMOST_MESSAGE_SIZEUNIT', mapi_prop_tag(PT_STRING8, 0x6719));
 
 /* storage for the settings for the webaccess 7.xx */
-define('PR_EC_RECIPIENT_HISTORY_JSON', mapi_prop_tag(PT_STRING8, 0x6773));
+if (!defined('PR_EC_RECIPIENT_HISTORY_JSON')) {
+	define('PR_EC_RECIPIENT_HISTORY_JSON', mapi_prop_tag(PT_STRING8, 0x6773));
+}
 
 /* The persistent settings are settings that will not be touched when the settings are reset */
-define('PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON', mapi_prop_tag(PT_STRING8, 0x6774));
-
+if (!defined('PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON')) {
+	define('PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON', mapi_prop_tag(PT_STRING8, 0x6774));
+}
 define('PR_EC_DISABLED_FEATURES', mapi_prop_tag(PT_MV_TSTRING, 0x67B4));
 
 define('PR_EC_ARCHIVE_SERVERS', mapi_prop_tag(PT_MV_TSTRING, 0x67C4));
